hstrat.hstrat.stratum\_retention\_condemners.StratumRetentionCondemnerDepthProportionalResolution
=================================================================================================

.. currentmodule:: hstrat.hstrat.stratum_retention_condemners

.. autoclass:: StratumRetentionCondemnerDepthProportionalResolution

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~StratumRetentionCondemnerDepthProportionalResolution.CalcMrcaUncertaintyUpperBound
      ~StratumRetentionCondemnerDepthProportionalResolution.CalcNumStrataRetainedExact
      ~StratumRetentionCondemnerDepthProportionalResolution.CalcNumStrataRetainedUpperBound
      ~StratumRetentionCondemnerDepthProportionalResolution.CalcRankAtColumnIndex
      ~StratumRetentionCondemnerDepthProportionalResolution.__init__
   
   

   
   
   